﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">
  <xsl:strip-space elements="*" />
  <xsl:output standalone="yes" method="html" encoding="utf-8" doctype-public="-//W3C//DTD XHTML+RDFa 1.0//EN" doctype-system="http://www.w3.org/MarkUp/DTD/xhtml-rdfa-1.dtd" indent="yes"/>
  <xsl:variable name="prenomNom">
    <xsl:value-of select="cv/coordonnees/prenom"/>
    <xsl:text>&#160;</xsl:text>
    <xsl:value-of select="cv/coordonnees/nom"/>
  </xsl:variable>
  <xsl:template match="cv">
    <html version="XHTML+RDFa 1.0" lang="fr" xml:lang="fr">
      <head xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:geo="http://www.w3.org/2003/01/geo/wgs84_pos#" xmlns:xsd="http://www.w3.org/2001/XMLSchema#">
      <!--  avec la version RDFa 1.1 on préférerea déclarer les préfixes ainsi : prefix="foaf: http://xmlns.com/foaf/0.1/" -->
        <meta http-equiv="Content-Type" content="application/xhtml+xml; charset=utf-8" />
        <title>CV : <xsl:value-of select="$prenomNom"/>
        </title>
        <xsl:copy-of select ="metadonnees/meta" />
        <meta name="description">
          <xsl:attribute name="content">
            <xsl:value-of select="objectif"/>
          </xsl:attribute>
        </meta>
        <link href="cv.css" type="text/css" rel="stylesheet" media="screen" charset="utf-8" />
      </head>
      <body>
        <div xmlns:foaf="http://xmlns.com/foaf/0.1/" id="wraper">
          <xsl:call-template name="body"/>
        </div>
      </body>
    </html>
    <!-- entete  -->
  </xsl:template>
  <xsl:template name="body">
    <div about="#me" typeof="foaf:Person" id="left">
    <span/>
      <h1>
        <a>
          <xsl:attribute name="href">
            <xsl:value-of select="metadonnees/meta[@property='dc:source']/@content"/>
          </xsl:attribute>
          <xsl:value-of select="coordonnees/prenom"/>
          <br/>
          <xsl:value-of select="coordonnees/nom"/>
        </a>
      </h1>
      <div class="widget">
        <p class="about">
        <span rel="foaf:depiction">
          <img alt="About Me">
            <xsl:attribute name="src">images/<xsl:value-of select="metadonnees/meta[@property='dc:identifier']/@content"/>.jpg</xsl:attribute>
          </img>
        </span>
        <br/>
        <span property="foaf:name"><xsl:value-of select="$prenomNom"/></span>
        </p>
        <p>
          <!-- Pour afficher l'adresse postale, décommentez les lignes suivantes
          <span class="adr">
            <span class="street-address">
              TODO plusieurs addrline avant ou après le numéro et le nom de la voie
              <xsl:value-of select="coordonnees/adresse/numero"/>&#160;<xsl:value-of select="coordonnees/adresse/voie"/>
              <br />
              <xsl:value-of select="coordonnees/adresse/addrline"/>
            </span>
            <br />
            <span class="postal-code">
              <xsl:value-of select="coordonnees/adresse/codepostal"/>
            </span>
            <xsl:text>&#160;</xsl:text>
            <span class="locality">
              <xsl:value-of select="coordonnees/adresse/ville"/>
            </span>
          </span>
          <br />
          <br /> -->
          <xsl:for-each select="coordonnees/contact">
            <xsl:if test="@type='Mobile'">
              <xsl:value-of select="@type"/>&#160;:
              <a rel="foaf:phone"><xsl:attribute name="href">tel:<xsl:value-of select="."/></xsl:attribute><xsl:value-of select="."/></a>
            </xsl:if>
            <xsl:if test="@type='Courriel'">
              <xsl:value-of select="@type"/>&#160;:
              <a rel="foaf:mbox"><xsl:attribute name="href">mailto:<xsl:value-of select="."/></xsl:attribute><xsl:value-of select="."/></a>
            </xsl:if>
            <br />
          </xsl:for-each>
        </p>
        <p class="summary"><xsl:value-of select="objectif"/>.</p>
          <p>
          <xsl:value-of select="langues/@libelle"/>&#160;:<xsl:for-each select="langues/langue">
            <xsl:value-of select="."/>
            <br/>
          </xsl:for-each>
          <xsl:apply-templates  select="pdp"/>
        </p>
        <p><a xmlns:cc="http://creativecommons.org/ns#" rel="cc:license" href="http://creativecommons.org/licenses/by/deed.fr"><img alt="Licence Creative Commons" style="border-width:0" src="http://i.creativecommons.org/l/by/3.0/88x31.png" /></a><br />Les fichiers, créés par <span xmlns:cc="http://creativecommons.org/ns#" property="cc:attributionName">Emmanuel Pierrez</span>, permettent de réaliser ce <span xmlns:dct="http://purl.org/dc/terms/" property="dct:title">CV</span>. Ils sont mis à disposition selon les termes de la <a rel="license" href="http://creativecommons.org/licenses/by/3.0/deed.fr">licence Creative Commons Attribution 3.0 non transposé</a>.</p>
      </div>
    </div>
    <div id="right">
      <div id="content">
        <h1 class="hidden">CV</h1>
        <div class="post_content">
          <!-- 1ere div  -->
          <div id="experiences">
            <h2>
              <xsl:value-of select="experiences/@libelle"/>
            </h2>
            <ul>
              <xsl:for-each select="experiences/experience">
                <li class="experience">
                  <div class="experience-dates">
                    <xsl:apply-templates select="annee"/>
                  </div>
                  <div>
                    <xsl:apply-templates select="libelle"/>
                  </div>
                </li>
              </xsl:for-each>
            </ul>
          </div>
          <!-- 2eme div  -->
          <div id="publications">
            <h2>
              <xsl:value-of select="publications/@libelle"/>
            </h2>
            <ul>
              <xsl:for-each select="publications/publication">
                <li class="experience">
                  <xsl:choose>
                    <xsl:when test="count(auteur)=1">
                      <span>
                        <xsl:value-of  select="auteur"/>
                      </span>
                    </xsl:when>
                    <xsl:when test="count(auteur)>2"><span>
                        <xsl:value-of  select="auteur[1]"/>
                      </span>
                      <xsl:text>&#160;et al.</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                      <span>
                        <xsl:value-of  select="auteur[1]"/>
                      </span>
                      <xsl:text>,&#160;</xsl:text>
                      <span>
                        <xsl:value-of  select="auteur[2]"/>
                      </span>
                    </xsl:otherwise>
                  </xsl:choose>
                  <xsl:text>&#160;-&#160;</xsl:text>
                  <xsl:apply-templates select="libelle"/>
                  <xsl:if test="in != ''">
                    <i>&#160;in&#160;<xsl:apply-templates select="in"/>
                    </i>
                  </xsl:if>
                  <xsl:text>,&#160;</xsl:text>
                  <xsl:value-of  select="annee"/>
                  <xsl:if test="lieuEdition != ''">
                    <xsl:text>,&#160;</xsl:text>
                    <xsl:value-of  select="lieuEdition"/>
                  </xsl:if>
                  <xsl:if test="editeur != ''">
                    <xsl:text>,&#160;</xsl:text>
                    <xsl:value-of  select="editeur"/>
                  </xsl:if>
                  <xsl:if test="pagination != ''">
                    <xsl:text>,&#160;</xsl:text>
                    <xsl:value-of  select="pagination"/>
                  </xsl:if>
                </li>
              </xsl:for-each>
            </ul>
          </div>
          <!-- 3eme div  -->
          <div id="interets">
            <h2>
              <xsl:value-of select="activites/@libelle"/>
            </h2>
            <ul>
              <xsl:for-each select="activites/experience">
                <li>
                  <xsl:apply-templates select="libelle"/>
                  <xsl:if test="annee != ''">
                    <xsl:text>,</xsl:text>
                    <xsl:apply-templates select="libelle"/>
                  </xsl:if>.
                </li>
              </xsl:for-each>
            </ul>
          </div>
          <!-- 4eme div  -->
          <div id="formation">
            <h2>
              <xsl:value-of select="formations/@libelle"/>
            </h2>
            <ul>
              <xsl:for-each select="formations/formation">
                <li class="education">
                  <span class="summary">
                    <xsl:value-of select="diplome"/>
                  </span>
                  <xsl:if test="mention != ''">,&#160;mention&#160;<xsl:apply-templates select="mention"/>
                  </xsl:if>
                  <xsl:if test="organisme != ''">
                    <xsl:apply-templates select="organisme"/>
                  </xsl:if>
                  <xsl:apply-templates select="lieu"/>
                  <!-- </div> --></li>
              </xsl:for-each>
            </ul>
          </div>
        </div>
      </div>
    </div>
  </xsl:template>
  <!-- templates  -->
  <xsl:template match="libelle">
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="titre">
    <strong class="title">
      <xsl:apply-templates/>
    </strong>
  </xsl:template>
  <xsl:template match="organisme">,&#160;<span class="org">
      <xsl:apply-templates/>
    </span>
  </xsl:template>
  <xsl:template match="lieu">,&#160;<span class="location">
      <xsl:value-of select="."/>
    </span>
    <xsl:if test="position()=last()">.</xsl:if>
  </xsl:template>
  <xsl:template match="annee">
    <xsl:if test="count(../annee)&gt;1">
      <abbr>
        <xsl:attribute name="class">
          <xsl:value-of select="@class"/>
        </xsl:attribute>
        <xsl:attribute name="title">
          <xsl:value-of select="."/>-01-01</xsl:attribute>
        <xsl:value-of select="."/>
      </abbr>
      <xsl:if test="position()=1"> - </xsl:if>
    </xsl:if>
    <xsl:if test="count(../annee)=1">
      <abbr>
        <xsl:attribute name="class">dtstart dtend</xsl:attribute>
        <xsl:attribute name="title">
          <xsl:value-of select="."/>-01-01</xsl:attribute>
        <xsl:value-of select="."/>
      </abbr>
    </xsl:if>
  </xsl:template>
  <xsl:template name="editeur">
    <xsl:value-of  select="editeur"/>
    <br />
  </xsl:template>
  <xsl:template match="lien">
    <a>
      <xsl:apply-templates select="@href|@show[.='new']|@title"/>
      <xsl:apply-templates/>
    </a>
  </xsl:template>
  <xsl:template match="@class">
    <xsl:attribute name="class">
      <xsl:value-of select="."/>
    </xsl:attribute>
  </xsl:template>
  <xsl:template match="@href">
    <xsl:attribute name="href">
      <xsl:value-of select="."/>
    </xsl:attribute>
  </xsl:template>
  <xsl:template match="@title">
    <xsl:attribute name="title">
      <xsl:value-of select="."/>
    </xsl:attribute>
  </xsl:template>
  <xsl:template match="@show[.='new']">
    <xsl:attribute name="target">_blank</xsl:attribute>
  </xsl:template>
</xsl:stylesheet>